@@ -1,8 +1,9 @@
 from rest_framework.fields import FileField as DRFFileField
 from rest_framework.fields import ImageField as DRFImageField
+from rest_framework.fields import Field
 
 
-class FileField(DRFFileField):
+class SafeFileFieldMixin(Field):
     def to_internal_value(self, data):
         current = getattr(self.parent.instance, self.field_name, None)
         if (
@@ -10,17 +11,13 @@ class FileField(DRFFileField):
             and current
             and data.endswith(getattr(current, "url", ""))
         ):
-            return getattr(current, "name", "")
+            return current
         return super().to_internal_value(data)
 
 
-class ImageField(DRFImageField):
-    def to_internal_value(self, data):
-        current = getattr(self.parent.instance, self.field_name, None)
-        if (
-            isinstance(data, str)
-            and current
-            and data.endswith(getattr(current, "url", ""))
-        ):
-            return getattr(current, "name", "")
-        return super().to_internal_value(data)
+class FileField(SafeFileFieldMixin, DRFFileField):
+    pass
+
+
+class ImageField(SafeFileFieldMixin, DRFImageField):
+    pass
